@@ -116,7 +116,13 @@ return_level_bingp <- function(x, m, level, ny, prof, inc, type, ny_given) {
   if (!prof) {
     return(list(rl_sym = rl_sym, rl_prof = NULL, rl_se = rl_se))
   }
-  temp <- bingp_rl_prof(x, m, level, ny, inc, type, rl_sym, u)
+  # CIs based on profile log-likelihood
+  # If k = 0 then use a function for which theta is set equal to 1
+  if (attr(x, "theta")$k > 0) {
+    temp <- bingp_rl_prof(x, m, level, ny, inc, type, rl_sym, u)
+  } else {
+    temp <- bingp_rl_prof0(x, m, level, ny, inc, type, rl_sym, u)
+  }
   return(list(rl_sym = rl_sym, rl_prof = temp$rl_prof, rl_se = rl_se,
               max_loglik = logLik(x), crit = temp$crit,
               for_plot = temp$for_plot))
@@ -167,9 +173,8 @@ bingp_rl_CI <- function (x, m, level, ny, type, u) {
 #' @keywords internal
 #' @rdname lite-internal
 bingp_rl_prof <- function(x, m, level, ny, inc, type, rl_sym, u) {
-  if (is.null(inc)) {
-    inc <- (rl_sym["upper"] - rl_sym["lower"]) / 100
-  }
+  # Convert inc to a length relative to the length of the symmetric CI
+  inc <- (rl_sym["upper"] - rl_sym["lower"]) * inc
   bingptheta_mle <- coef(x)
   # Function to calculate the negated adjusted binomial-GP log-likelihood
   bingp_negloglik <- function(pars, type) {
@@ -263,6 +268,107 @@ bingp_rl_prof <- function(x, m, level, ny, inc, type, rl_sym, u) {
               for_plot = cbind(ret_levs = ret_levs, prof_loglik = prof_lik)))
 }
 
+# Profile log-likelihood-based CIs in the K = 0 case, where theta is 1
+
+#' @keywords internal
+#' @rdname lite-internal
+bingp_rl_prof0 <- function(x, m, level, ny, inc, type, rl_sym, u) {
+  if (is.null(inc)) {
+    inc <- (rl_sym["upper"] - rl_sym["lower"]) / 100
+  }
+  bingptheta_mle <- coef(x)
+  # Function to calculate the negated adjusted binomial-GP log-likelihood
+  bingp_negloglik <- function(pars, type) {
+    return(-x(pars, type = type))
+  }
+  # Calculates the negated profile log-likelihood of the m-year return level
+  bingp_neg_prof_loglik <- function(a, xp) {
+    # a[1] is pu, a[2] is xi
+    # Check that pu is in (0, 1)
+    if (a[1] <= 0 || a[1] >= 1) {
+      return(10 ^ 10)
+    }
+    pmny <- 1 - (1 - 1 / m) ^ (1 / ny)
+    p <- pmny / a[1]
+    # Check that p is in [0, 1]
+    if (p > 1 || p < 0) {
+      return(10 ^ 10)
+    }
+    sigmau <- (xp - u) / revdbayes::qgp(p, loc = 0, scale = 1, shape = a[2],
+                                        lower.tail = FALSE)
+    # Check that sigmau is positive
+    if (sigmau <= 0) {
+      return(10 ^ 10)
+    }
+    bingp_pars <- c(a[1], sigmau, a[2], 1)
+    return(bingp_negloglik(bingp_pars, type = type))
+  }
+  max_loglik <- logLik(x)
+  rl_mle <- rl_sym["mle"]
+  conf_line <- max_loglik - 0.5 * stats::qchisq(level, 1)
+  v1 <- v2 <- x1 <- x2 <- NULL
+  x2[1] <- x1[1] <- rl_mle
+  v2[1] <- v1[1] <- max_loglik
+  #
+  # Starting from the MLE, we search upwards and downwards until we pass the
+  # cutoff for the 100level% confidence interval
+  #
+  ### Upper tail ...
+  xp <- rl_mle
+  my_val <- max_loglik
+  ii <- 1
+  sol <- bingptheta_mle[-c(2, 4)]
+  while (my_val > conf_line){
+    xp <- xp + inc
+    opt <- stats::optim(sol, bingp_neg_prof_loglik, method = "BFGS", xp = xp)
+    sol <- opt$par
+    ii <- ii + 1
+    x2[ii] <- xp
+    v2[ii] <- -opt$value
+    my_val <- v2[ii]
+  }
+  sol_up <- sol
+  ### Lower tail ...
+  xp <- rl_mle
+  my_val <- max_loglik
+  ii <- 1
+  sol <- bingptheta_mle[-c(2, 4)]
+  while (my_val > conf_line){
+    xp <- xp - inc
+    opt <- stats::optim(sol, bingp_neg_prof_loglik, method = "BFGS", xp = xp)
+    sol <- opt$par
+    ii <- ii + 1
+    x1[ii] <- xp
+    v1[ii] <- -opt$value
+    my_val <- v1[ii]
+  }
+  sol_low <- sol
+  #
+  # Find the limits of the confidence interval
+  #
+  prof_lik <- c(rev(v1), v2)
+  ret_levs <- c(rev(x1), x2)
+  # Find where the curve crosses conf_line
+  temp <- diff(prof_lik - conf_line > 0)
+  # Find the upper limit of the confidence interval
+  loc <- which(temp == -1)
+  x1 <- ret_levs[loc]
+  x2 <- ret_levs[loc + 1]
+  y1 <- prof_lik[loc]
+  y2 <- prof_lik[loc + 1]
+  up_lim <- x1 + (conf_line - y1) * (x2 - x1) / (y2 - y1)
+  # Find the lower limit of the confidence interval
+  loc <- which(temp == 1)
+  x1 <- ret_levs[loc]
+  x2 <- ret_levs[loc+1]
+  y1 <- prof_lik[loc]
+  y2 <- prof_lik[loc+1]
+  low_lim <- x1 + (conf_line - y1) * (x2 - x1) / (y2 - y1)
+  rl_prof <- c(lower = low_lim, rl_mle, upper = up_lim)
+  return(list(rl_prof = rl_prof, crit = conf_line,
+              for_plot = cbind(ret_levs = ret_levs, prof_loglik = prof_lik)))
+}
+
 # ============================== box_cox_deriv ============================== #
 
 #' @keywords internal
