@@ -13,7 +13,7 @@ if (got_exdex) {
   # Fit model
   cdata <- exdex::cheeseboro
   cfit <- flite(cdata, u = 45, k = 3)
-  rl <- returnLevel(cfit, inc = 5, ny = 31 * 24)
+  rl <- returnLevel(cfit, inc = 1 / 10, ny = 31 * 24)
 
   # Throw error
   test_that("plot.returnLevel error case", {
